<?php
/*
Plugin Name: Social Homes widget
Plugin URI: http://silentlycrashing.net/blog/repository/social-homes/
Description: Adds a sidebar widget containing a subtle list of all your social homes as linked favicons. Current services include del.icio.us, Flickr, YouTube, DailyMotion, Vimeo, Twitter, Last.fm, and LinkedIn. 
Author: Elie Zananiri
Author URI: http://www.silentlycrashing.net
Version: 2.0
Build: $Id: social-homes.php 36443 2008-03-27 18:44:46Z prisonerjohn $
*/

/*
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

// global services list
$services = array('del.icio.us', 'Flickr', 'YouTube', 'Vimeo', 'Dailymotion', 'Twitter', 'Last.fm', 'LinkedIn');

///////////////////////////////////////////////////////////////////////////////////////////
// Social Homes init
// all Social Homes functions are encapsulated here to ensure that widget 
// funtionality exists
// called at the plugins_loaded action
///////////////////////////////////////////////////////////////////////////////////////////
function widget_socialhomes_init() {
	
	// make sure the widget functionality exists before proceeding
	if ( !function_exists('register_sidebar_widget') )
		return;

	///////////////////////////////////////////////////////////////////////////////////////
	// Social Homes output
	// prints out the registered services in order as linked favicons
	///////////////////////////////////////////////////////////////////////////////////////
	function widget_socialhomes($args) {
		global $services;
		
		// $args is an array of strings that help widgets to conform to
		// the active theme: before_widget, before_title, after_widget,
		// and after_title are the array keys. Default tags: li and h2.
		extract($args);

		// load the Social Homes data
		$options = get_option('widget_socialhomes');
		
		// generate the output
		echo $before_widget . $before_title . $title . $after_title;
		$url_parts = parse_url(get_bloginfo('home'));
		echo '<div style="margin-top:5px;text-align:left;">';
		for ($i=0; $i < count($options); $i++) {
			if ($options[$i]['toggle']) {
				switch ($options[$i]['service']) {
					// del.icio.us
					case 0:
					$link = 'http://del.icio.us/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://del.icio.us/favicon.ico';
					break;
					// Flickr
					case 1:
					$link = 'http://www.flickr.com/people/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://www.flickr.com/favicon.ico';
					break;
					// YouTube
					case 2:
					$link = 'http://www.youtube.com/profile?user='.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://www.youtube.com/favicon.ico';
					break;
					// Vimeo
					case 3:
					$link = 'http://www.vimeo.com/user:'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://www.vimeo.com/favicon.ico';
					break;
					// Dailymotion
					case 4:
					$link = 'http://www.dailymotion.com/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://www.dailymotion.com/favicon.ico';
					break;
					// Twitter
					case 5:
					$link = 'http://twitter.com/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://twitter.com/favicon.ico';
					break;
					// Last.fm
					case 6:
					$link = 'http://www.last.fm/user/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://panther1.last.fm/matt/favicon.ico';
					break;
					// LinkedIn
					case 7:
					$link = 'http://www.linkedin.com/in/'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES);
					$icon = 'http://www.linkedin.com/favicon.ico';
					break;
				}
				// print the link
				echo '<a href="'.$link.'"><img width="16" height="16" src="'.$icon.'" alt="'.$services[$options[$i]['service']].'" /></a>&nbsp;&nbsp;';
			}
		}
		echo '</div>';
		echo $after_widget;
	}

	///////////////////////////////////////////////////////////////////////////////////////
	// Social Homes control form
	// sets up the services to register and the order to display them in
	///////////////////////////////////////////////////////////////////////////////////////
	function widget_socialhomes_control() {
		global $services;
		
		// get the data
		$options = get_option('widget_socialhomes');
		
		// create default data if none exists yet
		if (!is_array($options)) {
			// Set defaults
			$options = array();
			for ($i=0; $i < count($services); $i++) {
				$options[$i] = array('service'=>$i, 'toggle'=>0, 'handle'=>'username');
			}
		}
		
		// save the submitted data if there was a submit
		if ( $_POST['socialhomes-submit'] ) {
			// parse submitted data into the $options array
			for ($i=0; $i < count($services); $i++) {
				// service type
				$options[$i]['service'] = $_POST['socialhomes-'.$i.'-service'];
				
				// toggle status
				if ($_POST['socialhomes-'.$i.'-toggle']) 
					$options[$i]['toggle'] = ' checked';
				else 
					$options[$i]['toggle'] = '';
				
				// handle
				$options[$i]['handle'] = strip_tags(stripslashes($_POST['socialhomes-'.$i.'-handle']));
			}
			
			// save all the new data in the persistent storage
			update_option('widget_socialhomes', $options);
		}
		
		// print the control form
		for ($i=0; $i < count($services); $i++) {
			echo '<p style="text-align:left;">';
			// print a checkbox to enable or disable the service
		    echo '<input type="checkbox" id="socialhomes-'.$i.'-toggle" name="socialhomes-'.$i.'-toggle" '.$options[$i]['toggle'].'></input>';
			echo '&nbsp;&nbsp;&nbsp';
			// print the list of services as a drop-down menu
			echo '<select id="socialhomes-'.$i.'-service" name="socialhomes-'.$i.'-service">';
			for ($j=0; $j < count($services); $j++) {
				echo '<option value="'.$j.'"';
				if ($options[$i]['service'] == $j)
					echo ' selected="yes"';
				echo'>'.$services[$j].'</option>';
			}
			echo '</select>';
			echo '&nbsp;&nbsp;&nbsp';
			// print a text field for the handle
			echo '<input style="width: 150px;" id="socialhomes-'.$i.'-handle" name="socialhomes-'.$i.'-handle" type="text" value="'.htmlspecialchars($options[$i]['handle'], ENT_QUOTES).'" />';
			echo '</p>';
		}
		echo '<input type="hidden" id="socialhomes-submit" name="socialhomes-submit" value="1" />';
	}
	
	// registers Social Homes so it appears with the other available widgets and 
	// can be dragged and dropped into any active sidebars
	register_sidebar_widget(array('Social Homes', 'widgets'), 'widget_socialhomes');

	// registers the Social Homes control form
	register_widget_control(array('Social Homes', 'widgets'), 'widget_socialhomes_control', 315, 320);
}

// run the Social Homes code later in case it loads prior to any required plugins
add_action('widgets_init', 'widget_socialhomes_init');

?>
